==> poker-0.2.1.tar.gz: lib/src/models/card.dart <==
import "dart:math" as math;
import "package:meta/meta.dart";
import "package:poker/poker.dart";

/// A piece of playing cards.
@immutable
class Card implements Comparable {
  /// Creates a Card from Rank and Suit.
  const Card({required this.rank, required this.suit});

  /// Creates a Card from a hash int value.
  Card.fromInt(int value)
      : rank = Rank.values[(math.log(value) / math.log(2)).floor() % 13],
        suit = Suit.values[((math.log(value) / math.log(2)) / 13).floor()];

  /// Creates a card by a 2-character-length string (e.g. `"As"`, `"Th"` and `"2d"`).
  factory Card.fromString(String value) {
    if (!RegExp(r"^[A23456789TJQK][shdc]$").hasMatch(value)) {
      throw CardParseFailureException(value);
    }

    return Card(
      rank: _rankByString[value[0]]!,
      suit: _suitByString[value[1]]!,
    );
  }

  /// The Rank of this Card.
  final Rank rank;

  /// The Suit of this Card.
  final Suit suit;

  /// Returns the hash int value of this Card.
  int toInt() => math.pow(2, rank.index + suit.index * 13) as int;

  @override
  int compareTo(dynamic other) {
    if (other is! Card) return 0;

    if (suit.index != other.suit) {
      return suit.index - other.suit.index;
    }

    return rank.index - other.rank.index;
  }

  /// Returns a string representation. Ace of spade is `"As"`, 10 of heart is `"Th"` and 2 of diamond is `"2d"`.
  String toShortString() => "${rank.char}${suit.char}";

  @override
  String toString() => "Card<${toShortString()}>";

  @override
  int get hashCode => toInt();

  @override
  bool operator ==(Object other) =>
      other is Card && other.rank == rank && other.suit == suit;
}

class CardParseFailureException implements Exception {
  CardParseFailureException(this.value);

  final String value;

  @override
  String toString() {
    return "CardParseFailureException: $value is not a valid string.";
  }
}

const _rankByString = {
  "A": Rank.ace,
  "K": Rank.king,
  "Q": Rank.queen,
  "J": Rank.jack,
  "T": Rank.ten,
  "9": Rank.nine,
  "8": Rank.eight,
  "7": Rank.seven,
  "6": Rank.six,
  "5": Rank.five,
  "4": Rank.four,
  "3": Rank.trey,
  "2": Rank.deuce,
};

const _suitByString = {
  "s": Suit.spade,
  "h": Suit.heart,
  "d": Suit.diamond,
  "c": Suit.club,
};

==> poker-0.2.5.tar.gz: lib/src/models/card.dart <==
import "dart:math" as math;
import "package:meta/meta.dart";
import "package:poker/poker.dart";

/// A piece of playing cards.
@immutable
class Card implements Comparable {
  /// Creates a Card from Rank and Suit.
  Card({required this.rank, required this.suit})
      : _intValue = math.pow(2, rank.index + suit.index * 13).toInt();

  /// Creates a Card from a hash int value.
  Card.fromInt(int value)
      : rank = Rank.values[(math.log(value) / math.log(2)).floor() % 13],
        suit = Suit.values[((math.log(value) / math.log(2)) / 13).floor()],
        _intValue = value;

  /// Creates a card by a 2-character-length string (e.g. `"As"`, `"Th"` and `"2d"`).
  factory Card.fromString(String value) {
    if (!RegExp(r"^[A23456789TJQK][shdc]$").hasMatch(value)) {
      throw CardParseFailureException(value);
    }

    return Card(
      rank: _rankByString[value[0]]!,
      suit: _suitByString[value[1]]!,
    );
  }

  /// The Rank of this Card.
  final Rank rank;

  /// The Suit of this Card.
  final Suit suit;

  final int _intValue;

  /// Returns the hash int value of this Card.
  int toInt() => _intValue;

  @override
  int compareTo(dynamic other) {
    if (other is! Card) return 0;

    if (suit.index != other.suit) {
      return suit.index - other.suit.index;
    }

    return rank.index - other.rank.index;
  }

  /// Returns a string representation. Ace of spade is `"As"`, 10 of heart is `"Th"` and 2 of diamond is `"2d"`.
  String toShortString() => "${rank.char}${suit.char}";

  @override
  String toString() => "Card<${toShortString()}>";

  @override
  int get hashCode => toInt();

  @override
  bool operator ==(Object other) =>
      other is Card && other.rank == rank && other.suit == suit;
}

class CardParseFailureException implements Exception {
  CardParseFailureException(this.value);

  final String value;

  @override
  String toString() {
    return "CardParseFailureException: $value is not a valid string.";
  }
}

const _rankByString = {
  "A": Rank.ace,
  "K": Rank.king,
  "Q": Rank.queen,
  "J": Rank.jack,
  "T": Rank.ten,
  "9": Rank.nine,
  "8": Rank.eight,
  "7": Rank.seven,
  "6": Rank.six,
  "5": Rank.five,
  "4": Rank.four,
  "3": Rank.trey,
  "2": Rank.deuce,
};

const _suitByString = {
  "s": Suit.spade,
  "h": Suit.heart,
  "d": Suit.diamond,
  "c": Suit.club,
};
